@@ -1,25 +1,15 @@
-#
-# This file is part of Capture-Tiny
-#
-# This software is Copyright (c) 2009 by David Golden.
-#
-# This is free software, licensed under:
-#
-#   The Apache License, Version 2.0, January 2004
-#
 use 5.006;
 use strict;
 use warnings;
 package Capture::Tiny;
-BEGIN {
-  $Capture::Tiny::VERSION = '0.09';
-}
 # ABSTRACT: Capture STDOUT and STDERR from Perl, XS or external programs
+our $VERSION = '0.12'; # VERSION
 use Carp ();
 use Exporter ();
 use IO::Handle ();
 use File::Spec ();
 use File::Temp qw/tempfile tmpnam/;
+use Scalar::Util qw/reftype blessed/;
 # Get PerlIO or fake it
 BEGIN {
   local $@;
@@ -27,15 +17,41 @@ BEGIN {
     or *PerlIO::get_layers = sub { return () };
 }
 
+#--------------------------------------------------------------------------#
+# create API subroutines and export them
+# [do STDOUT flag, do STDERR flag, do merge flag, do tee flag]
+#--------------------------------------------------------------------------#
+
+my %api = (
+  capture         => [1,1,0,0],
+  capture_stdout  => [1,0,0,0],
+  capture_stderr  => [0,1,0,0],
+  capture_merged  => [1,0,1,0], # don't do STDERR since merging
+  tee             => [1,1,0,1],
+  tee_stdout      => [1,0,0,1],
+  tee_stderr      => [0,1,0,1],
+  tee_merged      => [1,0,1,1], # don't do STDERR since merging
+);
+
+for my $sub ( keys %api ) {
+  my $args = join q{, }, @{$api{$sub}};
+  eval "sub $sub(&;@) {unshift \@_, $args; goto \\&_capture_tee;}"; ## no critic
+}
+
 our @ISA = qw/Exporter/;
-our @EXPORT_OK = qw/capture capture_merged tee tee_merged/;
+our @EXPORT_OK = keys %api;
 our %EXPORT_TAGS = ( 'all' => \@EXPORT_OK );
 
+#--------------------------------------------------------------------------#
+# constants and fixtures
+#--------------------------------------------------------------------------#
+
 my $IS_WIN32 = $^O eq 'MSWin32';
 
 our $DEBUG = $ENV{PERL_CAPTURE_TINY_DEBUG};
+
 my $DEBUGFH;
-open $DEBUGFH, ">&STDERR" if $DEBUG;
+open $DEBUGFH, "> DEBUG" if $DEBUG;
 
 *_debug = $DEBUG ? sub(@) { print {$DEBUGFH} @_ } : sub(){0};
 
@@ -59,10 +75,10 @@ my @cmd = ($^X, '-e', '$SIG{HUP}=sub{exit}; '
 
 sub _relayer {
   my ($fh, $layers) = @_;
-  _debug("# requested layers (@{$layers}) to $fh\n");
+  _debug("# requested layers (@{$layers}) for @{[fileno $fh]}\n");
   my %seen = ( unix => 1, perlio => 1 ); # filter these out
   my @unique = grep { !$seen{$_}++ } @$layers;
-  _debug("# applying unique layers (@unique) to $fh\n");
+  _debug("# applying unique layers (@unique) to @{[fileno $fh]}\n");
   binmode($fh, join(":", ":raw", @unique));
 }
 
@@ -223,14 +239,20 @@ sub _fork_exec {
   $stash->{pid}{$which} = $pid
 }
 
-sub _files_exist { -f $_ || return 0 for @_; return 1 }
+my $have_usleep = eval "use Time::HiRes 'usleep'; 1";
+sub _files_exist {
+  return 1 if @_ == grep { -f } @_;
+  Time::HiRes::usleep(1000) if $have_usleep;
+  return 0;
+}
 
 sub _wait_for_tees {
   my ($stash) = @_;
   my $start = time;
   my @files = values %{$stash->{flag_files}};
-  my $timeout = $ENV{PERL_CAPTURE_TINY_TIMEOUT} || $TIMEOUT;
-  1 until _files_exist(@files) || ($TIMEOUT && (time - $start > $timeout));
+  my $timeout = defined $ENV{PERL_CAPTURE_TINY_TIMEOUT}
+              ? $ENV{PERL_CAPTURE_TINY_TIMEOUT} : $TIMEOUT;
+  1 until _files_exist(@files) || ($timeout && (time - $start > $timeout));
   Carp::confess "Timed out waiting for subprocesses to start" if ! _files_exist(@files);
   unlink $_ for @files;
 }
@@ -251,7 +273,9 @@ sub _kill_tees {
 }
 
 sub _slurp {
-  seek $_[0],0,0; local $/; return scalar readline $_[0];
+  my ($name, $fh) = @_;
+  _debug( "# slurping captured $name with layers: @{[PerlIO::get_layers($fh)]}\n");
+  seek $fh,0,0; local $/; return scalar readline $fh
 }
 
 #--------------------------------------------------------------------------#
@@ -260,7 +284,15 @@ sub _slurp {
 
 sub _capture_tee {
   _debug( "# starting _capture_tee with (@_)...\n" );
-  my ($tee_stdout, $tee_stderr, $merge, $code) = @_;
+  my ($do_stdout, $do_stderr, $do_merge, $do_tee, $code, @opts) = @_;
+  Carp::confess("Custom capture options must be given as key/value pairs\n")
+    unless @opts % 2 == 0;
+  my $stash = { capture => { @opts } };
+  for my $n ( keys %{$stash->{capture}} ) {
+    my $fh = $stash->{capture}{$n};
+    Carp::confess "Custom handle for $n must be seekable\n"
+      unless ref($fh) eq 'GLOB' || (blessed($fh) && $fh->isa("IO::Seekable"));
+  }
   # save existing filehandles and setup captures
   local *CT_ORIG_STDIN  = *STDIN ;
   local *CT_ORIG_STDOUT = *STDOUT;
@@ -272,86 +304,91 @@ sub _capture_tee {
     stderr  => [PerlIO::get_layers(\*STDERR)],
   );
   _debug( "# existing layers for $_\: @{$layers{$_}}\n" ) for qw/stdin stdout stderr/;
+  # get layers from underlying glob of tied filehandles if we can
+  # (this only works for things that work like Tie::StdHandle)
+  $layers{stdout} = [PerlIO::get_layers(tied *STDOUT)]
+    if tied(*STDOUT) && (reftype tied *STDOUT eq 'GLOB');
+  $layers{stderr} = [PerlIO::get_layers(tied *STDERR)]
+    if tied(*STDERR) && (reftype tied *STDERR eq 'GLOB');
+  _debug( "# tied object corrected layers for $_\: @{$layers{$_}}\n" ) for qw/stdin stdout stderr/;
   # bypass scalar filehandles and tied handles
   my %localize;
-  $localize{stdin}++,  local(*STDIN)  if grep { $_ eq 'scalar' } @{$layers{stdin}};
-  $localize{stdout}++, local(*STDOUT) if grep { $_ eq 'scalar' } @{$layers{stdout}};
-  $localize{stderr}++, local(*STDERR) if grep { $_ eq 'scalar' } @{$layers{stderr}};
-  $localize{stdout}++, local(*STDOUT), _open( \*STDOUT, ">&=1") if tied *STDOUT && $] >= 5.008;
-  $localize{stderr}++, local(*STDERR), _open( \*STDERR, ">&=2") if tied *STDERR && $] >= 5.008;
+  $localize{stdin}++,  local(*STDIN)
+    if grep { $_ eq 'scalar' } @{$layers{stdin}};
+  $localize{stdout}++, local(*STDOUT)
+    if $do_stdout && grep { $_ eq 'scalar' } @{$layers{stdout}};
+  $localize{stderr}++, local(*STDERR)
+    if ($do_stderr || $do_merge) && grep { $_ eq 'scalar' } @{$layers{stderr}};
+  $localize{stdout}++, local(*STDOUT), _open( \*STDOUT, ">&=1")
+    if $do_stdout && tied *STDOUT && $] >= 5.008;
+  $localize{stderr}++, local(*STDERR), _open( \*STDERR, ">&=2")
+    if ($do_stderr || $do_merge) && tied *STDERR && $] >= 5.008;
   _debug( "# localized $_\n" ) for keys %localize;
+  # proxy any closed/localized handles so we don't use fds 0, 1 or 2
   my %proxy_std = _proxy_std();
-  _debug( "# proxy std is @{ [%proxy_std] }\n" );
-  my $stash = { old => _copy_std() };
+  _debug( "# proxy std: @{ [%proxy_std] }\n" );
   # update layers after any proxying
-  %layers = (
-    stdin   => [PerlIO::get_layers(\*STDIN) ],
-    stdout  => [PerlIO::get_layers(\*STDOUT)],
-    stderr  => [PerlIO::get_layers(\*STDERR)],
-  );
+  $layers{stdin}  = [PerlIO::get_layers(\*STDIN)]  if $proxy_std{stdin};
+  $layers{stdout} = [PerlIO::get_layers(\*STDOUT)] if $proxy_std{stdout};
+  $layers{stderr} = [PerlIO::get_layers(\*STDERR)] if $proxy_std{stderr};
   _debug( "# post-proxy layers for $_\: @{$layers{$_}}\n" ) for qw/stdin stdout stderr/;
+  # store old handles and setup handles for capture
+  $stash->{old} = _copy_std();
+  $stash->{new} = { %{$stash->{old}} }; # default to originals
+  $stash->{new}{stdout} = ($stash->{capture}{stdout} ||= File::Temp->new) if $do_stdout;
+  $stash->{new}{stderr} = ($stash->{capture}{stderr} ||= File::Temp->new) if $do_stderr;
+  _debug("# will capture stdout on " . fileno($stash->{capture}{stdout})."\n" ) if $do_stdout;
+  _debug("# will capture stderr on " . fileno($stash->{capture}{stderr})."\n" ) if $do_stderr;
   # get handles for capture and apply existing IO layers
-  $stash->{new}{$_} = $stash->{capture}{$_} = File::Temp->new for qw/stdout stderr/;
-  _debug("# will capture $_ on " .fileno($stash->{capture}{$_})."\n" ) for qw/stdout stderr/;
   # tees may change $stash->{new}
-  _start_tee( stdout => $stash ) if $tee_stdout;
-  _start_tee( stderr => $stash ) if $tee_stderr;
-  _wait_for_tees( $stash ) if $tee_stdout || $tee_stderr;
+  _start_tee( stdout => $stash ) if $do_stdout && $do_tee;
+  _start_tee( stderr => $stash ) if $do_stderr && $do_tee;
+  _wait_for_tees( $stash ) if $do_tee;
   # finalize redirection
-  $stash->{new}{stderr} = $stash->{new}{stdout} if $merge;
-  $stash->{new}{stdin} = $stash->{old}{stdin};
+  $stash->{new}{stderr} = $stash->{new}{stdout} if $do_merge;
   _debug( "# redirecting in parent ...\n" );
   _open_std( $stash->{new} );
   # execute user provided code
-  my ($exit_code, $inner_error, $outer_error);
+  my ($exit_code, $inner_error, $outer_error, @result);
   {
     local *STDIN = *CT_ORIG_STDIN if $localize{stdin}; # get original, not proxy STDIN
-    local *STDERR = *STDOUT if $merge; # minimize buffer mixups during $code
+    local *STDERR = *STDOUT if $do_merge; # minimize buffer mixups during $code
     _debug( "# finalizing layers ...\n" );
-    _relayer(\*STDOUT, $layers{stdout});
-    _relayer(\*STDERR, $layers{stderr}) unless $merge;
+    _relayer(\*STDOUT, $layers{stdout}) if $do_stdout;
+    _relayer(\*STDERR, $layers{stderr}) if $do_stderr;
     _debug( "# running code $code ...\n" );
     local $@;
-    eval { $code->(); $inner_error = $@ };
+    eval { @result = $code->(); $inner_error = $@ };
     $exit_code = $?; # save this for later
     $outer_error = $@; # save this for later
   }
   # restore prior filehandles and shut down tees
-  _debug( "# restoring ...\n" );
+  _debug( "# restoring filehandles ...\n" );
   _open_std( $stash->{old} );
   _close( $_ ) for values %{$stash->{old}}; # don't leak fds
   _unproxy( %proxy_std );
-  _kill_tees( $stash ) if $tee_stdout || $tee_stderr;
+  _debug( "# killing tee subprocesses ...\n" ) if $do_tee;
+  _kill_tees( $stash ) if $do_tee;
   # return captured output
-  _relayer($stash->{capture}{stdout}, $layers{stdout});
-  _relayer($stash->{capture}{stderr}, $layers{stderr}) unless $merge;
-  _debug( "# slurping captured $_ with layers: @{[PerlIO::get_layers($stash->{capture}{$_})]}\n") for qw/stdout stderr/;
-  my $got_out = _slurp($stash->{capture}{stdout});
-  my $got_err = $merge ? q() : _slurp($stash->{capture}{stderr});
-  print CT_ORIG_STDOUT $got_out if $localize{stdout} && $tee_stdout;
-  print CT_ORIG_STDERR $got_err if !$merge && $localize{stderr} && $tee_stdout;
+  _relayer($stash->{capture}{stdout}, $layers{stdout}) if $do_stdout;
+  _relayer($stash->{capture}{stderr}, $layers{stderr}) if $do_stderr;
+  my $got_out = $do_stdout ? _slurp('stdout' => $stash->{capture}{stdout}) : q();
+  my $got_err = $do_stderr ? _slurp('stderr' => $stash->{capture}{stderr}) : q();
+  _debug("# slurped " . length($got_out) . " bytes from stdout\n");
+  _debug("# slurped " . length($got_err) . " bytes from stderr\n");
+  print CT_ORIG_STDOUT $got_out
+    if $do_stdout && $do_tee && $localize{stdout};
+  print CT_ORIG_STDERR $got_err
+    if $do_stderr && $do_tee && $localize{stderr};
   $? = $exit_code;
   $@ = $inner_error if $inner_error;
   die $outer_error if $outer_error;
   _debug( "# ending _capture_tee with (@_)...\n" );
-  return $got_out if $merge;
-  return wantarray ? ($got_out, $got_err) : $got_out;
-}
-
-#--------------------------------------------------------------------------#
-# create API subroutines from [tee STDOUT flag, tee STDERR, merge flag]
-#--------------------------------------------------------------------------#
-
-my %api = (
-  capture         => [0,0,0],
-  capture_merged  => [0,0,1],
-  tee             => [1,1,0],
-  tee_merged      => [1,0,1], # don't tee STDOUT since merging
-);
-
-for my $sub ( keys %api ) {
-  my $args = join q{, }, @{$api{$sub}};
-  eval "sub $sub(&) {unshift \@_, $args; goto \\&_capture_tee;}"; ## no critic
+  my @return;
+  push @return, $got_out if $do_stdout;
+  push @return, $got_err if $do_stderr;
+  push @return, @result;
+  return wantarray ? @return : $return[0];
 }
 
 1;
@@ -366,40 +403,36 @@ Capture::Tiny - Capture STDOUT and STDERR from Perl, XS or external programs
 
 =head1 VERSION
 
-version 0.09
+version 0.12
 
 =head1 SYNOPSIS
 
-   use Capture::Tiny qw/capture tee capture_merged tee_merged/;
+   use Capture::Tiny ':all';
  
-   ($stdout, $stderr) = capture {
+   ($stdout, $stderr, @result) = capture {
      # your code here
    };
  
+   $stdout = capture_stdout { ... };
+   $stderr = capture_stderr { ... };
+   $merged = capture_merged { ... };
+ 
    ($stdout, $stderr) = tee {
      # your code here
    };
  
-   $merged = capture_merged {
-     # your code here
-   };
- 
-   $merged = tee_merged {
-     # your code here
-   };
+   $stdout = tee_stdout { ... };
+   $stderr = tee_stderr { ... };
+   $merged = tee_merged { ... };
 
 =head1 DESCRIPTION
 
-Capture::Tiny provides a simple, portable way to capture anything sent to
-STDOUT or STDERR, regardless of whether it comes from Perl, from XS code or
+Capture::Tiny provides a simple, portable way to capture almost anything sent
+to STDOUT or STDERR, regardless of whether it comes from Perl, from XS code or
 from an external program.  Optionally, output can be teed so that it is
 captured while being passed through to the original handles.  Yes, it even
-works on Windows.  Stop guessing which of a dozen capturing modules to use in
-any particular situation and just use this one.
-
-This module was heavily inspired by L<IO::CaptureOutput>, which provides
-similar functionality without the ability to tee output and with more
-complicated code and API.
+works on Windows (usually).  Stop guessing which of a dozen capturing modules
+to use in any particular situation and just use this one.
 
 =head1 USAGE
 
@@ -407,13 +440,14 @@ The following functions are available.  None are exported by default.
 
 =head2 capture
 
-   ($stdout, $stderr) = capture \&code;
+   ($stdout, $stderr, @result) = capture \&code;
    $stdout = capture \&code;
 
 The C<<< capture >>> function takes a code reference and returns what is sent to
-STDOUT and STDERR.  In scalar context, it returns only STDOUT.  If no output
-was received, returns an empty string.  Regardless of context, all output is
-captured -- nothing is passed to the existing handles.
+STDOUT and STDERR as well as any return values from the code reference.  In
+scalar context, it returns only STDOUT.  If no output was received for a
+handle, it returns an empty string for that handle.  Regardless of calling
+context, all output is captured -- nothing is passed to the existing handles.
 
 It is prototyped to take a subroutine reference as an argument. Thus, it
 can be called in block form:
@@ -422,34 +456,85 @@ can be called in block form:
      # your code here ...
    };
 
+Note that the coderef is evaluated in list context.  If you wish to force
+scalar context on the return value, you must use the C<<< scalar >>> keyword.
+
+   ($stdout, $stderr, $count) = capture {
+     my @list = qw/one two three/;
+     return scalar @list; # $count will be 3
+   };
+
+Captures are normally done internally to an anonymous filehandle.  To
+capture via a named file (e.g. to externally monitor a long-running capture),
+provide custom filehandles as a trailing list of option pairs:
+
+   my $out_fh = IO::File->new("out.txt", "w+");
+   my $err_fh = IO::File->new("out.txt", "w+");
+   capture { ... } stdout => $out_fh, stderr => $err_fh;
+
+The filehandles must be readE<sol>write and seekable and should be empty.  Modifying
+the files externally during a capture operation will give unpredictable
+results.  Existing IO layers on them may be changed by the capture.
+
+=head2 capture_stdout
+
+   ($stdout, @result) = capture_stdout \&code;
+   $stdout = capture_stdout \&code;
+
+The C<<< capture_stdout >>> function works just like C<<< capture >>> except only
+STDOUT is captured.  STDERR is not captured.
+
+=head2 capture_stderr
+
+   ($stderr, @result) = capture_stderr \&code;
+   $stderr = capture_stderr \&code;
+
+The C<<< capture_stderr >>> function works just like C<<< capture >>> except only
+STDERR is captured.  STDOUT is not captured.
+
 =head2 capture_merged
 
+   ($merged, @result) = capture_merged \&code;
    $merged = capture_merged \&code;
 
 The C<<< capture_merged >>> function works just like C<<< capture >>> except STDOUT and
 STDERR are merged. (Technically, STDERR is redirected to STDOUT before
-executing the function.)  If no output was received, returns an empty string.
-As with C<<< capture >>> it may be called in block form.
+executing the function.)
 
 Caution: STDOUT and STDERR output in the merged result are not guaranteed to be
 properly ordered due to buffering.
 
 =head2 tee
 
-   ($stdout, $stderr) = tee \&code;
+   ($stdout, $stderr, @result) = tee \&code;
    $stdout = tee \&code;
 
 The C<<< tee >>> function works just like C<<< capture >>>, except that output is captured
-as well as passed on to the original STDOUT and STDERR.  As with C<<< capture >>> it
-may be called in block form.
+as well as passed on to the original STDOUT and STDERR.
+
+=head2 tee_stdout
+
+   ($stdout, @result) = tee_stdout \&code;
+   $stdout = tee_stdout \&code;
+
+The C<<< tee_stdout >>> function works just like C<<< tee >>> except only
+STDOUT is teed.  STDERR is not teed (output goes to STDERR as usual).
+
+=head2 tee_stderr
+
+   ($stderr, @result) = tee_stderr \&code;
+   $stderr = tee_stderr \&code;
+
+The C<<< tee_stderr >>> function works just like C<<< tee >>> except only
+STDERR is teed.  STDOUT is not teed (output goes to STDOUT as usual).
 
 =head2 tee_merged
 
+   ($merged, @result) = tee_merged \&code;
    $merged = tee_merged \&code;
 
 The C<<< tee_merged >>> function works just like C<<< capture_merged >>> except that output
-is captured as well as passed on to STDOUT.  As with C<<< capture >>> it may be called
-in block form.
+is captured as well as passed on to STDOUT.
 
 Caution: STDOUT and STDERR output in the merged result are not guaranteed to be
 properly ordered due to buffering.
@@ -466,17 +551,37 @@ particularly esoteric platforms yet.
 
 Capture::Tiny does it's best to preserve PerlIO layers such as ':utf8' or
 ':crlf' when capturing.   Layers should be applied to STDOUT or STDERR I<before>
-the call to C<<< capture >>> or C<<< tee >>>.
+the call to C<<< capture >>> or C<<< tee >>>.  This may not work for tied handles (see below).
 
-=head2 Closed STDIN, STDOUT or STDERR
+=head2 Modifying filehandles before capturing
+
+Generally speaking, you should do little or no manipulation of the standard IO
+handles prior to using Capture::Tiny.  In particular, closing, reopening,
+localizing or tying standard handles prior to capture may cause a variety of
+unexpected, undesireable andE<sol>or unreliable behaviors, as described below.
+Capture::Tiny does its best to compensate for these situations, but the
+results may not be what you desire.
+
+B<Closed filehandles>
 
 Capture::Tiny will work even if STDIN, STDOUT or STDERR have been previously
-closed.  However, since they may be reopened to capture or tee output, any code
-within the captured block that depends on finding them closed will, of course,
-not find them to be closed.  If they started closed, Capture::Tiny will reclose
-them again when the capture block finishes.
+closed.  However, since they will be reopened to capture or tee output, any
+code within the captured block that depends on finding them closed will, of
+course, not find them to be closed.  If they started closed, Capture::Tiny will
+reclose them again when the capture block finishes.
 
-=head2 Scalar filehandles and STDIN, STDOUT or STDERR
+Note that this reopening will happen even for STDIN or a handle not being
+captured to ensure that the filehandle used for capture is not opened to file
+descriptor 0, as this causes problems on various platforms.
+
+B<Localized filehandles>
+
+If code localizes any of Perl's standard handles before capturing, the capture
+will affect the localized handles and not the original ones.  External system
+calls are not affected by localizing a handle in Perl and will continue
+to send output to the original handles (which will thus not be captured).
+
+B<Scalar filehandles>
 
 If STDOUT or STDERR are reopened to scalar filehandles prior to the call to
 C<<< capture >>> or C<<< tee >>>, then Capture::Tiny will override the output handle for the
@@ -486,20 +591,23 @@ output handle after the capture is complete.  (Requires Perl 5.8)
 Capture::Tiny attempts to preserve the semantics of STDIN opened to a scalar
 reference.
 
-=head2 Tied STDIN, STDOUT or STDERR
+B<Tied handles>
 
 If STDOUT or STDERR are tied prior to the call to C<<< capture >>> or C<<< tee >>>, then
 Capture::Tiny will attempt to override the tie for the duration of the
 C<<< capture >>> or C<<< tee >>> call and then send captured output to the tied handle after
 the capture is complete.  (Requires Perl 5.8)
 
-Capture::Tiny does not (yet) support resending utf8 encoded data to a tied
-STDOUT or STDERR handle.  Characters will appear as bytes.
+Capture::Tiny may not succeed resending utf8 encoded data to a tied
+STDOUT or STDERR handle.  Characters may appear as bytes.  If the tied handle
+is based on L<Tie::StdHandle>, then Capture::Tiny will attempt to determine
+appropriate layers like C<<< :utf8 >>> from the underlying handle and do the right
+thing.
 
 Capture::Tiny attempts to preserve the semantics of tied STDIN, but capturing
 or teeing when STDIN is tied is currently broken on Windows.
 
-=head2 Modifiying STDIN, STDOUT or STDERR during a capture
+=head2 Modifiying handles during a capture
 
 Attempting to modify STDIN, STDOUT or STDERR I<during> C<<< capture >>> or C<<< tee >>> is
 almost certainly going to cause problems.  Don't do that.
@@ -516,7 +624,7 @@ Capture::Tiny uses subprocesses for C<<< tee >>>.  By default, Capture::Tiny wil
 timeout with an error if the subprocesses are not ready to receive data within
 30 seconds (or whatever is the value of C<<< $Capture::Tiny::TIMEOUT >>>).  An
 alternate timeout may be specified by setting the C<<< PERL_CAPTURE_TINY_TIMEOUT >>>
-environment variable.
+environment variable.  Setting it to zero will disable timeouts.
 
 =head1 BUGS
 
@@ -529,7 +637,13 @@ existing test-file that illustrates the bug or desired feature.
 
 =head1 SEE ALSO
 
-This is a selection of CPAN modules that provide some sort of output capture,
+This module was, inspired by L<IO::CaptureOutput>, which provides
+similar functionality without the ability to tee output and with more
+complicated code and API.  L<IO::CaptureOutput> does not handle layers
+or most of the unusual cases described in the L</Limitations> section and
+I no longer recommend it.
+
+There are many other CPAN modules that provide some sort of output capture,
 albeit with various limitations that make them appropriate only in particular
 circumstances.  I'm probably missing some.  The long list is provided to show
 why I felt Capture::Tiny was necessary.
@@ -622,6 +736,25 @@ L<Test::Output>
 
 =back
 
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders
+
+=head1 SUPPORT
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-capture-tiny at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/Public/Dist/Display.html?Name=Capture-Tiny>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+This is open source software.  The code repository is available for
+public review and contribution under the terms of the license.
+
+L<https://github.com/dagolden/capture-tiny>
+
+  git clone https://github.com/dagolden/capture-tiny.git
+
 =head1 AUTHOR
 
 David Golden <dagolden@cpan.org>
